/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](https://docs.oracle.com/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The member of a Data Guard group. Represents either a PRIMARY or a STANDBY Data Guard instance.
 */
export interface DataGuardGroupMember {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DB system, Cloud VM cluster or VM cluster.
     */
    "dbSystemId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Database.
     */
    "databaseId": string;
    /**
     * The role of the reporting database in this Data Guard association.
     */
    "role": DataGuardGroupMember.Role;
    /**
      * The lag time between updates to the primary database and application of the redo data on the standby database,
  * as computed by the reporting database.
  * <p>
  Example: {@code 1 second}
  *
      */
    "applyLag"?: string;
    /**
      * The rate at which redo logs are synced between the associated databases.
  * <p>
  Example: {@code 102.96 MByte/s}
  *
      */
    "applyRate"?: string;
    /**
      * The rate at which redo logs are transported between the associated databases.
  * <p>
  Example: {@code 1 second}
  *
      */
    "transportLag"?: string;
    /**
     * The date and time when last redo transport has been done.
     */
    "transportLagRefresh"?: string;
    /**
      * The redo transport type to use for this Data Guard association.  Valid values depend on the specified {@code protectionMode}:
  * <p>
  * MAXIMUM_AVAILABILITY - SYNC or FASTSYNC
  * * MAXIMUM_PERFORMANCE - ASYNC
  * * MAXIMUM_PROTECTION - SYNC
  * <p>
  For more information, see
  * [Redo Transport Services](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400)
  * in the Oracle Data Guard documentation.
  * <p>
  **IMPORTANT** - The only transport type currently supported by the Database service is ASYNC.
  *
      */
    "transportType"?: DataGuardGroupMember.TransportType;
    /**
     * True if active Data Guard is enabled.
     */
    "isActiveDataGuardEnabled"?: boolean;
}
export declare namespace DataGuardGroupMember {
    enum Role {
        Primary = "PRIMARY",
        Standby = "STANDBY",
        DisabledStandby = "DISABLED_STANDBY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum TransportType {
        Sync = "SYNC",
        Async = "ASYNC",
        Fastsync = "FASTSYNC",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DataGuardGroupMember): object;
    function getDeserializedJsonObj(obj: DataGuardGroupMember): object;
}
