/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](https://docs.oracle.com/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Details of an execution window.
 *
 */
export interface ExecutionWindowSummary {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the execution window.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the execution resource the execution window belongs to.
     */
    "executionResourceId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The user-friendly name for the execution window. The name does not need to be unique.
     */
    "displayName": string;
    /**
     * Description of the execution window.
     */
    "description"?: string;
    /**
     * The current state of the Schedule Policy. Valid states are CREATED, SCHEDULED, IN_PROGRESS, FAILED, CANCELED,
     * UPDATING, DELETED, SUCCEEDED and PARTIAL_SUCCESS.
     *
     */
    "lifecycleState": ExecutionWindowSummary.LifecycleState;
    /**
     * The current sub-state of the execution window. Valid states are DURATION_EXCEEDED, MAINTENANCE_IN_PROGRESS and WAITING.
     *
     */
    "lifecycleSubstate"?: ExecutionWindowSummary.LifecycleSubstate;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The date and time the execution window was created.
     */
    "timeCreated"?: Date;
    /**
     * The last date and time that the execution window was updated.
     */
    "timeUpdated"?: Date;
    /**
     * The date and time that the execution window was started.
     */
    "timeStarted"?: Date;
    /**
     * The date and time that the execution window ended.
     */
    "timeEnded"?: Date;
    /**
     * The scheduled start date and time of the execution window.
     */
    "timeScheduled": Date;
    /**
     * Duration window allows user to set a duration they plan to allocate for Scheduling window. The duration is in minutes.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "windowDurationInMins": number;
    /**
     * Indicates if duration the user plans to allocate for scheduling window is strictly enforced. The default value is {@code FALSE}.
     */
    "isEnforcedDuration"?: boolean;
    /**
     * The estimated time of the execution window in minutes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "estimatedTimeInMins"?: number;
    /**
     * The total time taken by corresponding resource activity in minutes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "totalTimeTakenInMins"?: number;
    /**
     * The execution window is of PLANNED or UNPLANNED type.
     */
    "windowType"?: ExecutionWindowSummary.WindowType;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ExecutionWindowSummary {
    enum LifecycleState {
        Created = "CREATED",
        Scheduled = "SCHEDULED",
        InProgress = "IN_PROGRESS",
        Failed = "FAILED",
        Canceled = "CANCELED",
        Updating = "UPDATING",
        Deleted = "DELETED",
        Succeeded = "SUCCEEDED",
        PartialSuccess = "PARTIAL_SUCCESS",
        Creating = "CREATING",
        Deleting = "DELETING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleSubstate {
        DurationExceeded = "DURATION_EXCEEDED",
        MaintenanceInProgress = "MAINTENANCE_IN_PROGRESS",
        Waiting = "WAITING",
        Rescheduled = "RESCHEDULED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum WindowType {
        Planned = "PLANNED",
        Unplanned = "UNPLANNED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ExecutionWindowSummary): object;
    function getDeserializedJsonObj(obj: ExecutionWindowSummary): object;
}
