/**
 * Full Stack Disaster Recovery API
 * Use the Full Stack Disaster Recovery (DR) API to manage disaster recovery for business applications.
Full Stack DR is an OCI disaster recovery orchestration and management service that provides comprehensive disaster
recovery capabilities for all layers of an application stack, including infrastructure, middleware, database,
and application.

 * OpenAPI spec version: 20220125
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Create backup configuration properties for an OKE member.
 */
export interface CreateOkeClusterBackupConfigDetails {
    /**
      * A list of namespaces that need to be backed up.
  * The default value is null. If a list of namespaces is not provided, all namespaces will be backed up.
  * This property applies to the OKE cluster member in primary region.
  * <p>
  Example: [\"default\", \"pv-nginx\"]
  *
      */
    "namespaces"?: Array<string>;
    /**
      * The schedule for backing up namespaces to the destination region. If a backup schedule is not specified, only a single backup will be created.
  * This format of the string specifying the backup schedule must conform with RFC-5545 (see examples below).
  * This schedule will use the UTC timezone.
  * This property applies to the OKE cluster member in primary region.
  * <p>
  The backup frequency can be HOURLY, DAILY, WEEKLY or MONTHLY, and the upper and lower interval bounds are as follows
  *   HOURLY
  *     - Minimum = 1
  *     - Maximum = 24
  *   DAILY
  *     - Minimum = 1
  *     - Maximum = 30
  *   WEEKLY
  *     - Minimum = 1
  *     - Maximum = 1
  *   MONTHLY
  *     - Minimum = 1
  *     - Maximum = 12
  * <p>
  Examples:
  *         FREQ=WEEKLY;BYDAY=MO,WE;BYHOUR=10;INTERVAL=1 -> Run a backup every Monday and Wednesday at 10:00 AM.
  *         FREQ=WEEKLY;BYDAY=MO,WE;BYHOUR=10;INTERVAL=2 -> Invalid configuration (Cannot specify an interval of 2).
  * <p>
          FREQ=HOURLY;INTERVAL=25 -> Invalid configuration (Cannot specify an interval of 25).
  *         FREQ=HOURLY;INTERVAL=0 -> Invalid configuration (Cannot specify an interval of 0).
  *         FREQ=HOURLY;INTERVAL=24 -> Run a backup every 24 hours.
  *         FREQ=HOURLY;INTERVAL=1 -> Run a backup every hour.
  *         FREQ=HOURLY;BYMINUTE=30;INTERVAL=15 -> Run a backup every 15 hours at the 30th minute.
  *
  *         FREQ=DAILY;INTERVAL=31 -> Invalid configuration (Cannot specify an interval of 31).
  *         FREQ=DAILY;INTERVAL=0 -> Invalid configuration (Cannot specify an interval of 0).
  *         FREQ=DAILY;INTERVAL=30 -> Run a backup every 30 days at 12:00 midnight.
  *         FREQ=DAILY;BYHOUR=17;BYMINUTE=10;INTERVAL=1 -> Run a backup daily at 05:10 PM.
  *
      */
    "backupSchedule"?: string;
    /**
     * Controls the behaviour of image replication across regions.
     * Image replication is enabled by default for DR Protection Groups with a primary role.
     * This property applies to the OKE cluster member in primary region.
     *
     */
    "replicateImages"?: model.OkeClusterImageReplication;
    /**
     * The maximum number of backups that should be retained.
     * This property applies to the OKE cluster member in primary region.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxNumberOfBackupsRetained"?: number;
    /**
     * The OCID of the vault secret that stores the image credential.
     * This property applies to the OKE cluster member in both the primary and standby region.
     *
     */
    "imageReplicationVaultSecretId"?: string;
}
export declare namespace CreateOkeClusterBackupConfigDetails {
    function getJsonObj(obj: CreateOkeClusterBackupConfigDetails): object;
    function getDeserializedJsonObj(obj: CreateOkeClusterBackupConfigDetails): object;
}
