/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20230831
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about new Fleet.
 */
export interface CreateFleetDetails {
    /**
      * A user-friendly name. Does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My new resource}
  *
      */
    "displayName"?: string;
    /**
     * A user-friendly description. To provide some insight about the resource.
     * Avoid entering confidential information.
     *
     */
    "description"?: string;
    /**
     * Tenancy OCID
     */
    "compartmentId": string;
    /**
     * Type of the Fleet.
     * PRODUCT - A fleet of product-specific resources for a product type.
     * ENVIRONMENT - A fleet of environment-specific resources for a product stack.
     * GROUP - A fleet of a fleet of either environment or product fleets.
     * GENERIC - A fleet of resources selected dynamically or manually for reporting purposes
     *
     */
    "fleetType": string;
    /**
     * Products associated with the Fleet.
     */
    "products"?: Array<string>;
    /**
     * Product stack associated with the Fleet.
     * Applicable for ENVIRONMENT fleet types.
     *
     */
    "applicationType"?: string;
    /**
     * Environment Type associated with the Fleet.
     * Applicable for ENVIRONMENT fleet types.
     *
     */
    "environmentType"?: string;
    /**
     * Group Type associated with Group Fleet.
     *
     */
    "groupType"?: string;
    /**
     * Type of resource selection in a Fleet.
     * Select resources manually or select resources based on rules.
     *
     */
    "resourceSelectionType"?: string;
    "ruleSelectionCriteria"?: model.SelectionCriteria;
    "notificationPreferences"?: model.NotificationPreferences;
    /**
     * Resources associated with the Fleet if resourceSelectionType is MANUAL.
     */
    "resources"?: Array<model.AssociatedFleetResourceDetails>;
    /**
     * Credentials associated with the Fleet.
     */
    "credentials"?: Array<model.AssociatedFleetCredentialDetails>;
    /**
     * A value that represents if auto-confirming of the targets can be enabled.
     * This will allow targets to be auto-confirmed in the fleet without manual intervention.
     *
     */
    "isTargetAutoConfirm"?: boolean;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateFleetDetails {
    function getJsonObj(obj: CreateFleetDetails): object;
    function getDeserializedJsonObj(obj: CreateFleetDetails): object;
}
