/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20230831
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of the FleetResource.
 */
export interface FleetResourceSummary {
    /**
     * The unique id of the resource.
     */
    "id": string;
    /**
     * OCID of the tenancy to which the resource belongs to.
     */
    "tenancyId": string;
    /**
     * Associated region
     */
    "resourceRegion"?: string;
    /**
     * The time this resource was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time this resource was last updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated"?: Date;
    /**
     * OCID of the compartment to which the resource belongs to.
     */
    "compartmentId": string;
    /**
      * A user-friendly name. Does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My new resource}
  *
      */
    "displayName": string;
    /**
     * The OCID of the resource.
     */
    "resourceId": string;
    /**
     * Compliance State of the Resource.
     */
    "complianceState"?: model.ComplianceState;
    /**
     * Resource Tenancy Name.
     */
    "tenancyName"?: string;
    /**
     * Resource Compartment name.
     */
    "compartment"?: string;
    /**
     * Type of the Resource.
     */
    "resourceType": string;
    /**
     * Count of products within the resource. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "productCount"?: number;
    /**
     * Count of targets within the resource. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "targetCount"?: number;
    /**
     * Product associated with the resource when the resource type is fleet.
     * Will only be returned for PRODUCT fleets that are part of a GROUP Fleet.
     *
     */
    "product"?: string;
    /**
     * Application Type associated with the resource when the resource type is fleet.
     * Will only be returned for ENVIRONMENT fleets that are part of a GROUP Fleet.
     *
     */
    "applicationType"?: string;
    /**
     * Environment Type associated with the Fleet when the resource type is fleet.
     * Will only be returned for ENVIRONMENT fleets that are part of a GROUP Fleet.
     *
     */
    "environmentType"?: string;
    /**
     * The current state of the FleetResource.
     */
    "lifecycleState": string;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace FleetResourceSummary {
    function getJsonObj(obj: FleetResourceSummary): object;
    function getDeserializedJsonObj(obj: FleetResourceSummary): object;
}
