/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20230831
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of the SchedulerJob.
 */
export interface SchedulerJobSummary {
    /**
     * The OCID of the resource.
     */
    "id": string;
    /**
      * A user-friendly name. Does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My new resource}
  *
      */
    "displayName": string;
    /**
     * Tenancy OCID
     */
    "compartmentId": string;
    /**
     * The time this resource was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time this resource was last updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated"?: Date;
    /**
     * The scheduled date and time for the Job.
     */
    "timeScheduled"?: Date;
    /**
     * Count of Action Groups affected by the Schedule.
     * An action group is a group of entities grouped for a lifecycle activity.
     * Example - A Fleet will be considered an Action Group for any lifecycle activity.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "countOfAffectedActionGroups"?: number;
    /**
     * Count of resources affected by the schedule. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "countOfAffectedResources"?: number;
    /**
     * Count of targets affected by the schedule. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "countOfAffectedTargets"?: number;
    /**
     * All Action Group types are part of the schedule.
     */
    "actionGroupTypes"?: Array<SchedulerJobSummary.ActionGroupTypes>;
    /**
     * All application types that are part of the schedule for an ENVIRONMENT action group Type.
     */
    "applicationTypes"?: Array<string>;
    /**
     * All products that are part of the schedule for a PRODUCT action group type.
     */
    "products"?: Array<string>;
    /**
     * All LifeCycle Operations that are part of the schedule.
     */
    "lifecycleOperations"?: Array<string>;
    /**
     * Action Groups associated with the Schedule.
     */
    "actionGroups"?: Array<model.ActionGroupDetails>;
    "associatedScheduleDefinition"?: model.AssociatedSchedulerDefinition;
    /**
     * The current state of the SchedulerJob.
     */
    "lifecycleState": string;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace SchedulerJobSummary {
    enum ActionGroupTypes {
        Product = "PRODUCT",
        Environment = "ENVIRONMENT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SchedulerJobSummary): object;
    function getDeserializedJsonObj(obj: SchedulerJobSummary): object;
}
