/**
 * File Storage with Lustre API
 * Use the File Storage with Lustre API to manage Lustre file systems and related resources. For more information, see [File Storage with Lustre](https://docs.oracle.com/iaas/Content/lustre/home.htm).
 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary information about a Lustre file system.
 */
export interface LustreFileSystemSummary {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Lustre file system.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the Lustre file system.
     */
    "compartmentId": string;
    /**
      * The availability domain the file system is in. May be unset
  * as a blank or NULL value.
  * <p>
  Example: {@code Uocm:PHX-AD-1}
  *
      */
    "availabilityDomain": string;
    /**
      * A user-friendly name. It does not have to be unique, and it is changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My Lustre file system}
  *
      */
    "displayName": string;
    /**
     * Short description of the Lustre file system.
     * Avoid entering confidential information.
     *
     */
    "fileSystemDescription": string;
    /**
      * The date and time the Lustre file system was created, expressed
  * in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
  * <p>
  Example: {@code 2024-04-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time the Lustre file system was updated, in the format defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2024-04-25T21:10:29.600Z}
  *
      */
    "timeUpdated": Date;
    /**
     * The current state of the Lustre file system.
     */
    "lifecycleState": string;
    /**
     * A message that describes the current state of the Lustre file system in more detail. For example,
     * can be used to provide actionable information for a resource in the Failed state.
     *
     */
    "lifecycleDetails"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags": {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A list of Network Security Group [OCIDs](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) associated with this lustre file system.
     * A maximum of 5 is allowed.
     * Setting this to an empty array after the list is created removes the lustre file system from all NSGs.
     * For more information about NSGs, see [Security Rules](https://docs.oracle.com/iaas/Content/Network/Concepts/securityrules.htm).
     *
     */
    "nsgIds"?: Array<string>;
    /**
     * The Lustre file system name. This is used in mount commands and other aspects of the client command line interface.
     * The default file system name is 'lustre'. The file system name is limited to 8 characters. Allowed characters are lower and upper case English letters, numbers, and '_'.
     *
     */
    "fileSystemName": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the KMS key used to encrypt the encryption keys associated with this file system.
     *
     */
    "kmsKeyId"?: string;
    /**
     * Capacity of the Lustre file system in GB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "capacityInGBs": number;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the Lustre file system is in.
     */
    "subnetId": string;
    /**
     * The Lustre file system performance tier. A value of {@code MBPS_PER_TB_125} represents 125 megabytes per second per terabyte.
     */
    "performanceTier": LustreFileSystemSummary.PerformanceTier;
    /**
      * The date and time the LustreFileSystem current billing cycle will end, expressed in
  * [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format. Once a cycle ends,
  * it is updated automatically to next timestamp which is after 30 days.
  * File systems deleted earlier will still incur charges till this date.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeBillingCycleEnd": Date;
    /**
      * The IPv4 address of MGS (Lustre Management Service) used by clients to mount the file system.
  * <p>
  Example: {@code 10.0.0.4}
  *
      */
    "managementServiceAddress": string;
    /**
      * Type of network used by clients to mount the file system.
  * <p>
  Example: {@code tcp}
  *
      */
    "lnet": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cluster placement group in which the Lustre file system exists.
     */
    "clusterPlacementGroupId"?: string;
    /**
      * Major version of Lustre running in the Lustre file system.
  * <p>
  Example: {@code 2.15}
  *
      */
    "majorVersion": string;
    "rootSquashConfiguration": model.RootSquashConfiguration;
}
export declare namespace LustreFileSystemSummary {
    enum PerformanceTier {
        MbpsPerTb125 = "MBPS_PER_TB_125",
        MbpsPerTb250 = "MBPS_PER_TB_250",
        MbpsPerTb500 = "MBPS_PER_TB_500",
        MbpsPerTb1000 = "MBPS_PER_TB_1000",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: LustreFileSystemSummary): object;
    function getDeserializedJsonObj(obj: LustreFileSystemSummary): object;
}
