/**
 *
 *
 * OpenAPI spec version: 20180401
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
/**
 * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/monitoring/ListAlarmSuppressions.ts.html |here} to see how to use ListAlarmSuppressionsRequest.
 */
export interface ListAlarmSuppressionsRequest extends common.BaseRequest {
    /**
     * Customer part of the request identifier token. If you need to contact Oracle about a particular
     * request, please provide the complete request ID.
     *
     */
    "opcRequestId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm that is the target of the alarm suppression.
     */
    "alarmId"?: string;
    /**
     * A filter to return only resources that match the given display name exactly.
     * Use this filter to list an alarm suppression by name.
     * Alternatively, when you know the alarm suppression OCID, use the GetAlarmSuppression operation.
     *
     */
    "displayName"?: string;
    /**
     * A filter to return only resources that match the given lifecycle state exactly. When not specified, only resources in the ACTIVE lifecycle state are listed.
     *
     */
    "lifecycleState"?: string;
    /**
     * The level of this alarm suppression.
     * {@code ALARM} indicates a suppression of the entire alarm, regardless of dimension.
     * {@code DIMENSION} indicates a suppression configured for specified dimensions.
     *
     */
    "level"?: string;
    /**
   * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for searching.
  * Use the tenancy OCID to search in the root compartment.
  * <p>
  If targetType is not specified, searches all suppressions defined under the compartment.
  * If targetType is {@code COMPARTMENT}, searches suppressions in the specified compartment only.
  * <p>
  Example: {@code ocid1.compartment.oc1..exampleuniqueID}
  *
   */
    "compartmentId"?: string;
    /**
     * When true, returns resources from all compartments and subcompartments. The parameter can
     * only be set to true when compartmentId is the tenancy OCID (the tenancy is the root compartment).
     * A true value requires the user to have tenancy-level permissions. If this requirement is not met,
     * then the call is rejected. When false, returns resources from only the compartment specified in
     * compartmentId. Default is false.
     *
     */
    "compartmentIdInSubtree"?: boolean;
    /**
     * The target type to use when listing alarm suppressions.
     * {@code ALARM} lists all suppression records for the specified alarm.
     * {@code COMPARTMENT} lists all suppression records for the specified compartment or tenancy.
     *
     */
    "targetType"?: ListAlarmSuppressionsRequest.TargetType;
    /**
   * Setting this parameter to true requires the query to specify the alarm ({@code alarmId}).
  * <p>
  When true, lists all alarm suppressions that affect the specified alarm,
  * including suppressions that target the corresponding compartment or tenancy.
  * When false, lists only the alarm suppressions that target the specified alarm.
  * <p>
  Default is false.
  *
   */
    "isAllSuppressions"?: boolean;
    /**
   * The field to use when sorting returned alarm suppressions. Only one sorting level is provided.
  * <p>
  Example: {@code timeCreated}
  *
   */
    "sortBy"?: ListAlarmSuppressionsRequest.SortBy;
    /**
   * The sort order to use when sorting returned alarm suppressions. Ascending (ASC) or descending (DESC).
  * <p>
  Example: {@code ASC}
  *
   */
    "sortOrder"?: ListAlarmSuppressionsRequest.SortOrder;
    /**
     * For list pagination. The value of the {@code opc-next-page} response header from the previous \"List\" call.
     * For important details about how pagination works, see
     * [List Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
     *
     */
    "page"?: string;
    /**
   * For list pagination. The maximum number of results per page, or items to return in a paginated \"List\" call.
  * For important details about how pagination works, see
  * [List Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
  * <p>
  Default: 1000
  * <p>
  Example: 500
  *
   */
    "limit"?: number;
}
export declare namespace ListAlarmSuppressionsRequest {
    enum TargetType {
        Alarm = "ALARM",
        Compartment = "COMPARTMENT"
    }
    enum SortBy {
        DisplayName = "displayName",
        TimeCreated = "timeCreated",
        TimeSuppressFrom = "timeSuppressFrom"
    }
    enum SortOrder {
        Asc = "ASC",
        Desc = "DESC"
    }
}
