/**
 * MySQL Database Service API
 * The API for the MySQL Database Service
 * OpenAPI spec version: 20190415
 * Contact: mysql-cloud-dev_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * User-defined service variables.
 */
export interface ConfigurationVariables {
    /**
     * (\"completion_type\")
     */
    "completionType"?: ConfigurationVariables.CompletionType;
    /**
      * If enabled, the server stores all temporary tables on disk rather than in memory.
  * <p>
  bigTables corresponds to the MySQL server variable [big_tables](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_big_tables).
  *
      */
    "bigTables"?: boolean;
    /**
      * The server's default character set. If you set this variable, you should also set collation_server to specify the collation for the character set.
  * <p>
  characterSetServer corresponds to the MySQL server variable [character_set_server](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_character_set_server).
  *
      */
    "characterSetServer"?: ConfigurationVariables.CharacterSetServer;
    /**
      * The server's default collation.
  * <p>
  collationServer corresponds to the MySQL server variable [collation_server](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_collation_server).
  *
      */
    "collationServer"?: ConfigurationVariables.CollationServer;
    /**
      * Set the chunking size for updates to the global memory usage counter Global_connection_memory.
  * <p>
  connectionMemoryChunkSize corresponds to the MySQL system variable [connection_memory_chunk_size](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_connection_memory_chunk_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "connectionMemoryChunkSize"?: number;
    /**
      * Set the maximum amount of memory that can be used by a single user connection.
  * <p>
  connectionMemoryLimit corresponds to the MySQL system variable [connection_memory_limit](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_connection_memory_limit).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "connectionMemoryLimit"?: number;
    /**
      * The default authentication plugin. This must be a plugin that uses internal credentials storage, so these values are permitted:
  * mysql_native_password, sha256_password, caching_sha2_password.
  * <p>
  As of MySQL 8.0.27, which introduces multifactor authentication, default_authentication_plugin is still used,
  * but in conjunction with and at a lower precedence than the authentication_policy system variable.
  * For details, see The Default Authentication Plugin. Because of this diminished role, default_authentication_plugin is deprecated as of MySQL 8.0.27
  * and subject to removal in a future MySQL version.
  * <p>
  defaultAuthenticationPlugin corresponds to the MySQL system variable
  * [default_authentication_plugin](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_default_authentication_plugin).
  *
      */
    "defaultAuthenticationPlugin"?: ConfigurationVariables.DefaultAuthenticationPlugin;
    /**
      * Set the total amount of memory that can be used by all user connections.
  * <p>
  globalConnectionMemoryLimit corresponds to the MySQL system variable [global_connection_memory_limit](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_global_connection_memory_limit).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "globalConnectionMemoryLimit"?: number;
    /**
      * Determines whether the MySQL server calculates Global_connection_memory.
  * <p>
  globalConnectionMemoryTracking corresponds to the MySQL system variable [global_connection_memory_tracking](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_global_connection_memory_tracking).
  *
      */
    "globalConnectionMemoryTracking"?: boolean;
    /**
     * (\"transaction_isolation\")
     */
    "transactionIsolation"?: ConfigurationVariables.TransactionIsolation;
    /**
     * (\"innodb_ft_server_stopword_table\")
     */
    "innodbFtServerStopwordTable"?: string;
    /**
     * (\"mandatory_roles\")
     */
    "mandatoryRoles"?: string;
    /**
     * (\"autocommit\")
     */
    "autocommit"?: boolean;
    /**
     * (\"foreign_key_checks\")
     */
    "foreignKeyChecks"?: boolean;
    /**
     * - EVENTUAL:
     *     Both RO and RW transactions do not wait for preceding transactions to be applied before executing.
     *     A RW transaction does not wait for other members to apply a transaction. This means that a transaction
     *     could be externalized on one member before the others. This also means that in the event of a primary failover,
     *     the new primary can accept new RO and RW transactions before the previous primary transactions are all applied.
     *     RO transactions could result in outdated values, RW transactions could result in a rollback due to conflicts.
     * - BEFORE_ON_PRIMARY_FAILOVER:
     *     New RO or RW transactions with a newly elected primary that is applying backlog from the old
     *     primary are held (not applied) until any backlog has been applied. This ensures that when a primary failover happens,
     *     intentionally or not, clients always see the latest value on the primary. This guarantees consistency, but means that
     *     clients must be able to handle the delay in the event that a backlog is being applied. Usually this delay should be minimal,
     *     but does depend on the size of the backlog.
     * - BEFORE:
     *     A RW transaction waits for all preceding transactions to complete before being applied. A RO transaction waits for all preceding
     *     transactions to complete before being executed. This ensures that this transaction reads the latest value by only affecting the
     *     latency of the transaction. This reduces the overhead of synchronization on every RW transaction, by ensuring synchronization is
     *     used only on RO transactions. This consistency level also includes the consistency guarantees provided by BEFORE_ON_PRIMARY_FAILOVER.
     * - AFTER:
     *     A RW transaction waits until its changes have been applied to all of the other members. This value has no effect on RO transactions.
     *     This mode ensures that when a transaction is committed on the local member, any subsequent transaction reads the written value or
     *     a more recent value on any group member. Use this mode with a group that is used for predominantly RO operations to ensure that
     *     applied RW transactions are applied everywhere once they commit. This could be used by your application to ensure that subsequent
     *     reads fetch the latest data which includes the latest writes. This reduces the overhead of synchronization on every RO transaction,
     *     by ensuring synchronization is used only on RW transactions. This consistency level also includes the consistency guarantees
     *     provided by BEFORE_ON_PRIMARY_FAILOVER.
     * - BEFORE_AND_AFTER:
     *     A RW transaction waits for 1) all preceding transactions to complete before being applied and 2) until its changes have been
     *     applied on other members. A RO transaction waits for all preceding transactions to complete before execution takes place.
     *     This consistency level also includes the consistency guarantees provided by BEFORE_ON_PRIMARY_FAILOVER.
     *
     */
    "groupReplicationConsistency"?: ConfigurationVariables.GroupReplicationConsistency;
    /**
      * Specifies the maximum permitted result length in bytes for the GROUP_CONCAT() function.
  * <p>
  This is the MySQL variable \"group_concat_max_len\". For more information, please see the [MySQL documentation](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_group_concat_max_len)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "groupConcatMaxLen"?: number;
    /**
     * (\"innodb_ft_enable_stopword\")
     */
    "innodbFtEnableStopword"?: boolean;
    /**
      * Enables dedicated log writer threads for writing redo log records from the log buffer to the system buffers and flushing the system buffers to the redo log files.
  * <p>
  This is the MySQL variable \"innodb_log_writer_threads\". For more information, please see the [MySQL documentation](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_log_writer_threads)
  *
      */
    "innodbLogWriterThreads"?: boolean;
    /**
      * This variable controls server-side LOCAL capability for LOAD DATA statements. Depending on the local_infile setting,
  * the server refuses or permits local data loading by clients that have LOCAL enabled on the client side.
  * <p>
  local_infile corresponds to the MySQL Server system variable
  * [local_infile](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_local_infile)
  *
      */
    "localInfile"?: boolean;
    /**
     * (\"mysql_firewall_mode\")
     */
    "mysqlFirewallMode"?: boolean;
    /**
     * (\"mysqlx_enable_hello_notice\") DEPRECATED -- variable should not be settable and will be ignored
     */
    "mysqlxEnableHelloNotice"?: boolean;
    /**
     * (\"sql_require_primary_key\")
     */
    "sqlRequirePrimaryKey"?: boolean;
    /**
     * (\"sql_warnings\")
     */
    "sqlWarnings"?: boolean;
    /**
     * Sets the binary log expiration period in seconds.
     * binlogExpireLogsSeconds corresponds to the MySQL binary logging system variable [binlog_expire_logs_seconds](https://dev.mysql.com/doc/refman/8.0/en/replication-options-binary-log.html#sysvar_binlog_expire_logs_seconds).
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "binlogExpireLogsSeconds"?: number;
    /**
     * Configures the amount of table metadata added to the binary log when using row-based logging.
     * binlogRowMetadata corresponds to the MySQL binary logging system variable [binlog_row_metadata](https://dev.mysql.com/doc/refman/8.0/en/replication-options-binary-log.html#sysvar_binlog_row_metadata).
     *
     */
    "binlogRowMetadata"?: ConfigurationVariables.BinlogRowMetadata;
    /**
     * When set to PARTIAL_JSON, this enables use of a space-efficient binary log format for updates that modify only a small portion of a JSON document.
     * binlogRowValueOptions corresponds to the MySQL binary logging system variable [binlog_row_value_options](https://dev.mysql.com/doc/refman/8.0/en/replication-options-binary-log.html#sysvar_binlog_row_value_options).
     *
     */
    "binlogRowValueOptions"?: string;
    /**
     * Enables compression for transactions that are written to binary log files on this server.
     * binlogTransactionCompression corresponds to the MySQL binary logging system variable [binlog_transaction_compression](https://dev.mysql.com/doc/refman/8.0/en/replication-options-binary-log.html#sysvar_binlog_transaction_compression).
     *
     */
    "binlogTransactionCompression"?: boolean;
    /**
      * The size (in bytes) of the buffer pool, that is, the memory area where InnoDB caches table and index data.
  * <p>
  innodbBufferPoolSize corresponds to the MySQL server system variable
  * [innodb_buffer_pool_size](https://dev.mysql.com/doc/refman/en/innodb-parameters.html#sysvar_innodb_buffer_pool_size).
  * <p>
  The default and maximum values depend on the amount of RAM provisioned by the shape.
  * See [Default User Variables](https://docs.oracle.com/iaas/mysql-database/doc/configuring-db-system.html#GUID-B5504C19-F6F4-4DAB-8506-189A4E8F4A6A).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbBufferPoolSize"?: number;
    /**
     * (\"innodb_ft_result_cache_limit\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbFtResultCacheLimit"?: number;
    /**
      * Sets the size of the transaction cache.
  * <p>
  maxBinlogCacheSize corresponds to the MySQL server system variable [max_binlog_cache_size](https://dev.mysql.com/doc/refman/8.0/en/replication-options-binary-log.html#sysvar_max_binlog_cache_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxBinlogCacheSize"?: number;
    /**
     * (\"max_connect_errors\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxConnectErrors"?: number;
    /**
      * This variable sets the maximum size to which user-created MEMORY tables are permitted to grow.
  * <p>
  maxHeapTableSize corresponds to the MySQL system variable
  * [max_heap_table_size](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_max_heap_table_size)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxHeapTableSize"?: number;
    /**
     * (\"max_connections\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxConnections"?: number;
    /**
     * (\"max_prepared_stmt_count\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxPreparedStmtCount"?: number;
    /**
      * The number of seconds that the mysqld server waits for a connect packet before responding with Bad handshake.
  * <p>
  connectTimeout corresponds to the MySQL system variable
  * [connect_timeout](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_connect_timeout)
  * <p>
  Increasing the connect_timeout value might help if clients frequently encounter errors of the form
  * \"Lost connection to MySQL server at 'XXX', system error: errno\".
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "connectTimeout"?: number;
    /**
     * (\"cte_max_recursion_depth\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cteMaxRecursionDepth"?: number;
    /**
     * (\"generated_random_password_length\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "generatedRandomPasswordLength"?: number;
    /**
     * (\"information_schema_stats_expiry\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "informationSchemaStatsExpiry"?: number;
    /**
      * Specifies the percentage of the most recently used pages for each buffer pool to read out and dump.
  * <p>
  innodbBufferPoolDumpPct corresponds to the MySQL InnoDB system variable
  * [innodb_buffer_pool_dump_pct](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_buffer_pool_dump_pct).
  * <p>
  The range is 1 to 100. The default value is 25.
  * <p>
  For example, if there are 4 buffer pools with 100 pages each, and innodb_buffer_pool_dump_pct is set to 25,
  * the 25 most recently used pages from each buffer pool are dumped.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbBufferPoolDumpPct"?: number;
    /**
     * (\"innodb_buffer_pool_instances\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbBufferPoolInstances"?: number;
    /**
     * innodbDdlBufferSize corresponds to the MySQL system variable [innodb_ddl_buffer_size] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_ddl_buffer_size)
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbDdlBufferSize"?: number;
    /**
     * innodbDdlThreads corresponds to the MySQL system variable [innodb_ddl_threads] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_ddl_threads)
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbDdlThreads"?: number;
    /**
     * (\"innodb_ft_max_token_size\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbFtMaxTokenSize"?: number;
    /**
     * (\"innodb_ft_min_token_size\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbFtMinTokenSize"?: number;
    /**
     * (\"innodb_ft_num_word_optimize\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbFtNumWordOptimize"?: number;
    /**
     * (\"innodb_lock_wait_timeout\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "innodbLockWaitTimeout"?: number;
    /**
      * The desired maximum purge lag in terms of transactions.
  * <p>
  InnoDB maintains a list of transactions that have index records delete-marked by UPDATE or DELETE operations. The length of the list is the purge lag.
  * <p>
  If this value is exceeded, a delay is imposed on INSERT, UPDATE, and DELETE operations to allow time for purge to catch up.
  * <p>
  The default value is 0, which means there is no maximum purge lag and no delay.
  * <p>
  innodbMaxPurgeLag corresponds to the MySQL server system variable
  * [innodb_max_purge_lag](https://dev.mysql.com/doc/refman/en/innodb-parameters.html#sysvar_innodb_max_purge_lag).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbMaxPurgeLag"?: number;
    /**
      * The maximum delay in microseconds for the delay imposed when the innodb_max_purge_lag threshold is exceeded.
  * <p>
  The specified innodb_max_purge_lag_delay value is an upper limit on the delay period.
  * <p>
  innodbMaxPurgeLagDelay corresponds to the MySQL server system variable
  * [innodb_max_purge_lag_delay](https://dev.mysql.com/doc/refman/en/innodb-parameters.html#sysvar_innodb_max_purge_lag_delay).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbMaxPurgeLagDelay"?: number;
    /**
      * The number of seconds the server waits for activity on an interactive connection before closing it.
  * <p>
  interactiveTimeout corresponds to the MySQL system variable.
  * [interactive_timeout](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_interactive_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "interactiveTimeout"?: number;
    /**
      * The number of index pages to sample when estimating cardinality and other statistics for an indexed column,
  * such as those calculated by ANALYZE TABLE.
  * <p>
  innodbStatsPersistentSamplePages corresponds to the MySQL InnoDB system variable
  * [innodb_stats_persistent_sample_pages](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_stats_persistent_sample_pages)
  * <p>
  innodb_stats_persistent_sample_pages only applies when innodb_stats_persistent is enabled for a table;
  * when innodb_stats_persistent is disabled, innodb_stats_transient_sample_pages applies instead.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbStatsPersistentSamplePages"?: number;
    /**
      * The number of index pages to sample when estimating cardinality and other statistics for an indexed column,
  * such as those calculated by [ANALYZE TABLE](https://dev.mysql.com/doc/refman/8.0/en/analyze-table.html).
  * <p>
  innodbStatsTransientSamplePages corresponds to the MySQL InnoDB system variable
  * [innodb_stats_transient_sample_pages](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_stats_transient_sample_pages)
  * <p>
  innodb_stats_transient_sample_pages only applies when innodb_stats_persistent is disabled for a table;
  * when innodb_stats_persistent is enabled, innodb_stats_persistent_sample_pages applies instead.
  * <p>
  innodb_stats_persistent is ON by default and cannot be changed. It is possible to override it using the
  * STATS_PERSISTENT clause of the [CREATE TABLE](https://dev.mysql.com/doc/refman/8.0/en/create-table.html) and
  * [ALTER TABLE](https://dev.mysql.com/doc/refman/8.0/en/alter-table.html) statements.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbStatsTransientSamplePages"?: number;
    /**
      * When you enable innodbStrictMode, the InnoDB storage engine returns errors instead of warnings for invalid or incompatible table options.
  * <p>
  innodbStrictMode corresponds to the MySQL InnoDB system variable
  * [innodb_strict_mode](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_strict_mode)
  *
      */
    "innodbStrictMode"?: boolean;
    /**
      * The maximum size of one packet or any generated/intermediate string.
  * <p>
  This is the mysql variable \"max_allowed_packet\".
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxAllowedPacket"?: number;
    /**
     * (\"max_execution_time\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxExecutionTime"?: number;
    /**
      * The number of seconds X Plugin waits for the first packet to be received from newly connected clients.
  * <p>
  mysqlxConnectTimeout corresponds to the MySQL X Plugin system variable
  * [mysqlx_connect_timeout](https://dev.mysql.com/doc/refman/8.0/en/x-plugin-options-system-variables.html#sysvar_mysqlx_connect_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxConnectTimeout"?: number;
    /**
     * (\"mysqlx_document_id_unique_prefix\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxDocumentIdUniquePrefix"?: number;
    /**
     * (\"mysqlx_idle_worker_thread_timeout\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxIdleWorkerThreadTimeout"?: number;
    /**
      * The number of seconds to wait for interactive clients to timeout.
  * <p>
  mysqlxInteractiveTimeout corresponds to the MySQL X Plugin system variable.
  * [mysqlx_interactive_timeout](https://dev.mysql.com/doc/refman/8.0/en/x-plugin-options-system-variables.html#sysvar_mysqlx_interactive_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxInteractiveTimeout"?: number;
    /**
      * The maximum size of network packets that can be received by X Plugin.
  * <p>
  This is the mysql variable \"mysqlx_max_allowed_packet\".
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxMaxAllowedPacket"?: number;
    /**
     * (\"mysqlx_min_worker_threads\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxMinWorkerThreads"?: number;
    /**
      * The number of seconds that X Plugin waits for blocking read operations to complete. After this time, if the
  * read operation is not successful, X Plugin closes the connection and returns a warning notice with the error
  * code ER_IO_READ_ERROR to the client application.
  * <p>
  mysqlxReadTimeout corresponds to the MySQL X Plugin system variable
  * [mysqlx_read_timeout](https://dev.mysql.com/doc/refman/8.0/en/x-plugin-options-system-variables.html#sysvar_mysqlx_read_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxReadTimeout"?: number;
    /**
      * The number of seconds that X Plugin waits for activity on a connection.
  * <p>
  mysqlxWaitTimeout corresponds to the MySQL X Plugin system variable.
  * [mysqlx_wait_timeout](https://dev.mysql.com/doc/refman/8.0/en/x-plugin-options-system-variables.html#sysvar_mysqlx_wait_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxWaitTimeout"?: number;
    /**
      * The number of seconds that X Plugin waits for blocking write operations to complete. After this time, if the
  * write operation is not successful, X Plugin closes the connection.
  * <p>
  mysqlxReadmysqlxWriteTimeoutTimeout corresponds to the MySQL X Plugin system variable
  * [mysqlx_write_timeout](https://dev.mysql.com/doc/refman/8.0/en/x-plugin-options-system-variables.html#sysvar_mysqlx_write_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "mysqlxWriteTimeout"?: number;
    /**
      * The number of seconds to wait for more data from a connection before aborting the read.
  * <p>
  netReadTimeout corresponds to the MySQL system variable
  * [net_read_timeout](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_net_read_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "netReadTimeout"?: number;
    /**
      * The number of seconds to wait for a block to be written to a connection before aborting the write.
  * <p>
  netWriteTimeout corresponds to the MySQL system variable
  * [net_write_timeout](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_net_write_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "netWriteTimeout"?: number;
    /**
     * (\"parser_max_mem_size\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "parserMaxMemSize"?: number;
    /**
     * (\"query_alloc_block_size\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "queryAllocBlockSize"?: number;
    /**
     * (\"query_prealloc_size\") DEPRECATED -- variable should not be settable and will be ignored Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "queryPreallocSize"?: number;
    /**
     * regexpTimeLimit corresponds to the MySQL system variable [regexp_time_limit] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_regexp_time_limit)
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "regexpTimeLimit"?: number;
    /**
     * (\"sql_mode\")
     */
    "sqlMode"?: string;
    /**
      * The maximum size of internal in-memory temporary tables. This variable does not apply to user-created MEMORY tables.
  * <p>
  tmp_table_size corresponds to the MySQL system variable
  * [tmp_table_size](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_tmp_table_size)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "tmpTableSize"?: number;
    /**
     * Set the default compression level for the deflate algorithm. (\"mysqlx_deflate_default_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxDeflateDefaultCompressionLevel"?: number;
    /**
     * Limit the upper bound of accepted compression levels for the deflate algorithm. (\"mysqlx_deflate_max_client_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxDeflateMaxClientCompressionLevel"?: number;
    /**
     * Limit the upper bound of accepted compression levels for the lz4 algorithm. (\"mysqlx_lz4_max_client_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxLz4MaxClientCompressionLevel"?: number;
    /**
     * Set the default compression level for the lz4 algorithm. (\"mysqlx_lz4_default_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxLz4DefaultCompressionLevel"?: number;
    /**
     * Limit the upper bound of accepted compression levels for the zstd algorithm. (\"mysqlx_zstd_max_client_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxZstdMaxClientCompressionLevel"?: number;
    /**
     * Set the default compression level for the zstd algorithm. (\"mysqlx_zstd_default_compression_level\") Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlxZstdDefaultCompressionLevel"?: number;
    /**
     * DEPRECATED -- typo of mysqlx_zstd_default_compression_level. variable will be ignored. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mysqlZstdDefaultCompressionLevel"?: number;
    /**
      * Each session that must perform a sort allocates a buffer of this size.
  * <p>
  sortBufferSize corresponds to the MySQL system variable [sort_buffer_size](https://dev.mysql.com/doc/refman/en/server-system-variables.html#sysvar_sort_buffer_size)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "sortBufferSize"?: number;
    /**
      * The number of seconds the server waits for activity on a noninteractive connection before closing it.
  * <p>
  waitTimeout corresponds to the MySQL system variable.
  * [wait_timeout](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_wait_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "waitTimeout"?: number;
    /**
     * Controls whether the thread pool uses dedicated listener threads. If enabled, a listener thread in each thread group is dedicated to the task of listening
     * for network events from clients, ensuring that the maximum number of query worker threads is no more than the value specified by threadPoolMaxTransactionsLimit.
     * threadPoolDedicatedListeners corresponds to the MySQL Database Service-specific system variable thread_pool_dedicated_listeners.
     *
     */
    "threadPoolDedicatedListeners"?: boolean;
    /**
     * Limits the maximum number of open transactions to the defined value. The default value is 0, which enforces no limit.
     * threadPoolMaxTransactionsLimit corresponds to the MySQL Database Service-specific system variable thread_pool_max_transactions_limit.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "threadPoolMaxTransactionsLimit"?: number;
    /**
      * Initializes the time zone for each client that connects.
  * <p>
  This corresponds to the MySQL System Variable \"time_zone\".
  * <p>
  The values can be given in one of the following formats, none of which are case-sensitive:
  * <p>
  - As a string indicating an offset from UTC of the form [H]H:MM, prefixed with a + or -, such as '+10:00', '-6:00', or '+05:30'. The permitted range is '-13:59' to '+14:00', inclusive.
  * - As a named time zone, as defined by the \"IANA Time Zone database\", such as 'Europe/Helsinki', 'US/Eastern', 'MET', or 'UTC'.
  *
      */
    "timeZone"?: string;
    /**
      * This variable controls the block encryption mode for block-based algorithms such as AES. It affects encryption for AES_ENCRYPT() and AES_DECRYPT().
  *
  * block_encryption_mode takes a value in aes-keylen-mode format, where keylen is the key length in bits and mode is the encryption mode. The value is not case-sensitive.
  * Permitted keylen values are 128, 192, and 256. Permitted mode values are ECB, CBC, CFB1, CFB8, CFB128, and OFB.
  * <p>
  block_encryption_mode corresponds to the MySQL Server Administration system variable
  * [block_encryption_mode](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_block_encryption_mode)
  *
      */
    "blockEncryptionMode"?: string;
    /**
      * Controls how many microseconds the binary log commit waits before synchronizing the binary log file to disk.
  * There is no delay by default. Setting this variable to a microsecond delay enables more transactions to be synchronized
  * together to disk at once, reducing the overall time to commit a group of transactions because the larger groups required
  * fewer time units per group.
  * <p>
  binlogGroupCommitSyncDelay corresponds to the MySQL Replication system variable
  * [binlog_group_commit_sync_delay](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_group_commit_sync_delay)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "binlogGroupCommitSyncDelay"?: number;
    /**
      * The maximum number of transactions to wait for before aborting the current delay as specified by binlog_group_commit_sync_delay.
  * If binlog_group_commit_sync_delay is set to 0, then this option has no effect.
  * <p>
  binlogGroupCommitSyncNoDelayCount corresponds to the MySQL Replication system variable
  * [binlog_group_commit_sync_no_delay_count](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_group_commit_sync_no_delay_count)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "binlogGroupCommitSyncNoDelayCount"?: number;
    /**
      * Specifies the number of seconds to wait for more data or a heartbeat signal from the source before the replica considers the connection broken,
  * aborts the read, and tries to reconnect. Setting this variable has no immediate effect. The state of the variable applies on all subsequent START REPLICA commands.
  * <p>
  replicaNetTimeout corresponds to the MySQL Replica server system variable
  * [replica_net_timeout](https://dev.mysql.com/doc/refman/8.0/en/replication-options-replica.html#sysvar_replica_net_timeout)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "replicaNetTimeout"?: number;
    /**
      * Whether client connections to the server are required to use some form of secure transport.
  * When this variable is enabled, the server permits only TCP/IP connections encrypted using TLS/SSL, or connections that use a socket file or shared memory.
  * The server rejects nonsecure connection attempts, which fail with an ER_SECURE_TRANSPORT_REQUIRED error.
  * <p>
  require_secure_transport corresponds to the MySQL Server Administration system variable
  * [require_secure_transport](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_require_secure_transport)
  *
      */
    "requireSecureTransport"?: boolean;
    /**
      * Defines the amount of disk space occupied by redo log files. innodb_redo_log_capacity supercedes the innodb_log_files_in_group and innodb_log_file_size variables,
  * which are both ignored if innodb_redo_log_capacity is defined. If innodb_redo_log_capacity is not defined, and if neither innodb_log_file_size or innodb_log_files_in_group are defined,
  * then the default innodb_redo_log_capacity value is used.
  * <p>
  innodbRedoLogCapacity corresponds to the InnoDB Startup Options and System Variables
  * [innodb_redo_log_capacity](https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_redo_log_capacity)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbRedoLogCapacity"?: number;
    /**
      * The delay period before executing a new transaction, in milliseconds. The maximum value is 300000 (5 minutes).
  * A transaction delay can be used in cases where parallel transactions affect the performance of other operations due to resource contention.
  * For example, if parallel transactions affect index creation or an online buffer pool resizing operation,
  * you can configure a transaction delay to reduce resource contention while those operations are running.
  * <p>
  threadPoolTransactionDelay corresponds to the MySQL Server system variable
  * [thread_pool_transaction_delay](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_thread_pool_transaction_delay)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "threadPoolTransactionDelay"?: number;
    /**
      * The maximum number of query threads permitted in a thread group.
  * The maximum value is 4096, but if thread_pool_max_transactions_limit is set, thread_pool_query_threads_per_group must not exceed that value.
  * The default value of 1 means there is one active query thread in each thread group, which works well for many loads.
  * When you are using the high concurrency thread pool algorithm (thread_pool_algorithm = 1),
  * consider increasing the value if you experience slower response times due to long-running transactions.
  * <p>
  threadPoolQueryThreadsPerGroup corresponds to the MySQL Server system variable
  * [thread_pool_query_threads_per_group](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_thread_pool_query_threads_per_group)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "threadPoolQueryThreadsPerGroup"?: number;
    /**
      * This variable determines the default output format used by EXPLAIN in the absence of a FORMAT option when displaying a query execution plan.
  * <p>
  explainFormat corresponds to the MySQL system variable
  * [explain_format](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_explain_format).
  *
      */
    "explainFormat"?: ConfigurationVariables.ExplainFormat;
    /**
      * This system variable determines whether the server enables certain nonstandard behaviors for default values and NULL-value handling in TIMESTAMP columns.
  * By default, explicit_defaults_for_timestamp is enabled, which disables the nonstandard behaviors. Disabling explicit_defaults_for_timestamp results in a warning.
  * <p>
  explicit_defaults_for_timestamp corresponds to the MySQL Server Administration system variable
  * [explicit_defaults_for_timestamp](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_explicit_defaults_for_timestamp)
  *
      */
    "explicitDefaultsForTimestamp"?: boolean;
    /**
      * Whether GIPK mode is in effect, in which case a MySQL replication source server adds a generated invisible primary key to any InnoDB table that is created without one.
  * <p>
  sqlGenerateInvisiblePrimaryKey corresponds to the MySQL system variable
  * [sql_generate_invisible_primary_key] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_sql_generate_invisible_primary_key).
  *
      */
    "sqlGenerateInvisiblePrimaryKey"?: boolean;
    /**
      * Defines the maximum amount of memory that can be occupied by the TempTable storage engine before it starts storing data on disk.
  * The default value is 1073741824 bytes (1GiB). For more information, see Section 10.4.4, \u201CInternal Temporary Table Use in MySQL\u201D.
  * <p>
  temptableMaxRam corresponds to the MySQL system variable
  * [temptable_max_ram] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_temptable_max_ram).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "temptableMaxRam"?: number;
    /**
      * Whether InnoDB performs change buffering, an optimization that delays write operations to secondary indexes so that the I/O operations can be performed sequentially.
  * Permitted values are described in the following table. Values may also be specified numerically.
  * <p>
  innodbChangeBuffering corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_change_buffering] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_change_buffering).
  *
      */
    "innodbChangeBuffering"?: ConfigurationVariables.InnodbChangeBuffering;
    /**
      * Whether the InnoDB adaptive hash index is enabled or disabled.
  * It may be desirable, depending on your workload, to dynamically enable or disable adaptive hash indexing to improve query performance.
  * Because the adaptive hash index may not be useful for all workloads, conduct benchmarks with it both enabled and disabled, using realistic workloads.
  * <p>
  innodbAdaptiveHashIndex corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_adaptive_hash_index] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_adaptive_hash_index).
  *
      */
    "innodbAdaptiveHashIndex"?: boolean;
    /**
      * When enabled, undo tablespaces that exceed the threshold value defined by innodb_max_undo_log_size are marked for truncation.
  * Only undo tablespaces can be truncated. Truncating undo logs that reside in the system tablespace is not supported.
  * For truncation to occur, there must be at least two undo tablespaces.
  * <p>
  innodbUndoLogTruncate corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_undo_log_truncate] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_undo_log_truncate).
  *
      */
    "innodbUndoLogTruncate"?: boolean;
    /**
      * The number of table definitions that can be stored in the table definition cache.
  * If you use a large number of tables, you can create a large table definition cache to speed up opening of tables.
  * The table definition cache takes less space and does not use file descriptors, unlike the normal table cache.
  * <p>
  table_definition_cache corresponds to the MySQL Server Administration system variable
  * [table_definition_cache](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_table_definition_cache)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "tableDefinitionCache"?: number;
    /**
      * The number of open tables for all threads. Increasing this value increases the number of file descriptors that mysqld requires.
  * <p>
  table_open_cache corresponds to the MySQL Server Administration system variable
  * [table_open_cache](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_table_open_cache)
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "tableOpenCache"?: number;
    /**
      * The maximum amount of space to use for all relay logs.
  * <p>
  relayLogSpaceLimit corresponds to the MySQL Replica Server Options variable
  * [relay_log_space_limit] (https://dev.mysql.com/doc/refman/8.0/en/replication-options-replica.html#sysvar_relay_log_space_limit).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "relayLogSpaceLimit"?: number;
    /**
      * The optimizer_switch system variable enables control over optimizer behavior.
  * The value of this variable is a set of flags, each of which has a value of on or off to indicate whether the corresponding optimizer behavior is enabled or disabled.
  * This variable has global and session values and can be changed at runtime. The global default can be set at server startup.
  * <p>
  Setting hypergraph_optimizer=on for cloud builds below 9.0.0 will fail.
  * <p>
  optimizerSwitch corresponds to the MySQL Server System variable
  * [optimizer_switch] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_optimizer_switch).
  *
      */
    "optimizerSwitch"?: string;
    /**
      * From MySQL 8.0.26, use replica_type_conversions in place of slave_type_conversions, which is deprecated from that release.
  * In releases before MySQL 8.0.26, use slave_type_conversions.
  * <p>
  replica_type_conversions controls the type conversion mode in effect on the replica when using row-based replication.
  * Its value is a comma-delimited set of zero or more elements from the list: ALL_LOSSY, ALL_NON_LOSSY, ALL_SIGNED, ALL_UNSIGNED.
  * Set this variable to an empty string to disallow type conversions between the source and the replica.
  * Setting this variable takes effect for all replication channels immediately, including running channels.
  * <p>
  replica_type_conversions corresponds to the MySQL Replica Server Options variable
  * [replica_type_conversions] (https://dev.mysql.com/doc/refman/8.0/en/replication-options-replica.html#sysvar_replica_type_conversions).
  *
      */
    "replicaTypeConversions"?: string;
    /**
      * Beginning with MySQL 8.0.26, slave_parallel_workers is deprecated, and you should use replica_parallel_workers instead.
  * (Prior to MySQL 8.0.26, you must use slave_parallel_workers to set the number of applier threads.)
  * <p>
  replicaParallelWorkers corresponds to the MySQL Replica Server Options variable
  * [replica_parallel_workers] (https://dev.mysql.com/doc/refman/8.0/en/replication-options-replica.html#sysvar_replica_parallel_workers).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "replicaParallelWorkers"?: number;
    /**
      * Whether to resolve host names when checking client connections. If this variable is OFF, mysqld resolves host names when checking client connections.
  * If it is ON, mysqld uses only IP numbers; in this case, all Host column values in the grant tables must be IP addresses.
  * See Section 7.1.12.3, \u201CDNS Lookups and the Host Cache\u201D.
  * <p>
  skipNameResolve corresponds to the MySQL Server System variable
  * [skip_name_resolve] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_skip_name_resolve).
  *
      */
    "skipNameResolve"?: boolean;
    /**
      * The maximum number of simultaneous connections permitted to any given MySQL user account.
  * A value of 0 (the default) means \u201Cno limit.\u201D This variable has a global value that can be set at server startup or runtime.
  * It also has a read-only session value that indicates the effective simultaneous-connection limit that applies to the account associated with the current session.
  * <p>
  maxUserConnections corresponds to the MySQL Server System variable
  * [max_user_connections] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_max_user_connections).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxUserConnections"?: number;
    /**
      * The minimum size of the buffer that is used for plain index scans, range index scans, and joins that do not use indexes and thus perform full table scans.
  * In MySQL 8.0.18 and later, this variable also controls the amount of memory used for hash joins. Normally, the best way to get fast joins is to add indexes.
  * Increase the value of join_buffer_size to get a faster full join when adding indexes is not possible. One join buffer is allocated for each full join between two tables.
  * For a complex join between several tables for which indexes are not used, multiple join buffers might be necessary.
  * <p>
  joinBufferSize corresponds to the MySQL Server System variable
  * [join_buffer_size] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_join_buffer_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "joinBufferSize"?: number;
    /**
      * Limit the assumed maximum number of seeks when looking up rows based on a key.
  * The MySQL optimizer assumes that no more than this number of key seeks are required when searching for matching rows in a table by scanning an index,
  * regardless of the actual cardinality of the index (see Section 15.7.7.22, \u201CSHOW INDEX Statement\u201D).
  * By setting this to a low value (say, 100), you can force MySQL to prefer indexes instead of table scans.
  * <p>
  maxSeeksForKey corresponds to the MySQL Server System variable
  * [max_seeks_for_key] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_max_seeks_for_key).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxSeeksForKey"?: number;
    /**
      * The limit on memory consumption for the range optimizer. A value of 0 means \u201Cno limit.\u201D
  * If an execution plan considered by the optimizer uses the range access method but the optimizer estimates that the amount of memory needed for this method would exceed the limit,
  * it abandons the plan and considers other plans.
  * <p>
  rangeOptimizerMaxMemSize corresponds to the MySQL Server System variable
  * [range_optimizer_max_mem_size] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_range_optimizer_max_mem_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "rangeOptimizerMaxMemSize"?: number;
    /**
      * auto_increment_increment and auto_increment_offset are intended for use with circular (source-to-source) replication,
  * and can be used to control the operation of AUTO_INCREMENT columns. Both variables have global and session values,
  * and each can assume an integer value between 1 and 65,535 inclusive.
  * <p>
  autoIncrementIncrement corresponds to the MySQL Replication Source Options variable
  * [auto_increment_increment] (https://dev.mysql.com/doc/refman/8.0/en/replication-options-source.html#sysvar_auto_increment_increment).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "autoIncrementIncrement"?: number;
    /**
      * This variable has a default value of 1. If it is left with its default value,
  * and Group Replication is started on the server in multi-primary mode, it is changed to the server ID.
  * <p>
  autoIncrementOffset corresponds to the MySQL Replication Source Options variable
  * [auto_increment_offset] (https://dev.mysql.com/doc/refman/8.0/en/replication-options-source.html#sysvar_auto_increment_offset).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "autoIncrementOffset"?: number;
    /**
      * The lock mode to use for generating auto-increment values.
  * Permissible values are 0, 1, or 2, for traditional, consecutive, or interleaved, respectively.
  * <p>
  innodbAutoincLockMode corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_autoinc_lock_mode] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_autoinc_lock_mode).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbAutoincLockMode"?: number;
    /**
      * InnoDB rolls back only the last statement on a transaction timeout by default.
  * If --innodb-rollback-on-timeout is specified, a transaction timeout causes InnoDB to abort and roll back the entire transaction.
  * <p>
  innodbRollbackOnTimeout corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_rollback_on_timeout] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_rollback_on_timeout).
  *
      */
    "innodbRollbackOnTimeout"?: boolean;
    /**
      * Specifies an upper limit in bytes on the size of the temporary log files used during online DDL operations for InnoDB tables.
  * There is one such log file for each index being created or table being altered.
  * This log file stores data inserted, updated, or deleted in the table during the DDL operation.
  * <p>
  innodbOnlineAlterLogMaxSize corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_online_alter_log_max_size] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_online_alter_log_max_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbOnlineAlterLogMaxSize"?: number;
    /**
      * This variable defines:
  * <p>
  * The sort buffer size for online DDL operations that create or rebuild secondary indexes.
  *   However, as of MySQL 8.0.27, this responsibility is subsumed by the innodb_ddl_buffer_size variable.
  * <p>
  * The amount by which the temporary log file is extended when recording concurrent DML during an online DDL operation,
  *   and the size of the temporary log file read buffer and write buffer.
  * <p>
  innodbSortBufferSize corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_sort_buffer_size] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_sort_buffer_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "innodbSortBufferSize"?: number;
    /**
      * Enables the NUMA interleave memory policy for allocation of the InnoDB buffer pool.
  * When innodb_numa_interleave is enabled, the NUMA memory policy is set to MPOL_INTERLEAVE for the mysqld process.
  * After the InnoDB buffer pool is allocated, the NUMA memory policy is set back to MPOL_DEFAULT.
  * For the innodb_numa_interleave option to be available, MySQL must be compiled on a NUMA-enabled Linux system.
  * <p>
  innodbNumaInterleave corresponds to the MySQL InnoDB Startup Options and System Variables
  * [innodb_numa_interleave] (https://dev.mysql.com/doc/refman/8.0/en/innodb-parameters.html#sysvar_innodb_numa_interleave).
  *
      */
    "innodbNumaInterleave"?: boolean;
    /**
      * The number of thread groups in the thread pool. This is the most important parameter controlling thread pool performance.
  * It affects how many statements can execute simultaneously. If a value outside the range of permissible values is specified,
  * the thread pool plugin does not load and the server writes a message to the error log.
  * <p>
  threadPoolSize corresponds to the MySQL Server System variable
  * [thread_pool_size] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_thread_pool_size).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "threadPoolSize"?: number;
    /**
      * If a query takes longer than this many seconds, the server increments the Slow_queries status variable.
  * If the slow query log is enabled, the query is logged to the slow query log file.
  * This value is measured in real time, not CPU time,
  * so a query that is under the threshold on a lightly loaded system might be above the threshold on a heavily loaded one.
  * <p>
  longQueryTime corresponds to the MySQL Server System variable
  * [long_query_time] (https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_long_query_time).
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "longQueryTime"?: number;
}
export declare namespace ConfigurationVariables {
    enum CompletionType {
        NoChain = "NO_CHAIN",
        Chain = "CHAIN",
        Release = "RELEASE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum CharacterSetServer {
        Armscii8 = "ARMSCII8",
        Ascii = "ASCII",
        Big5 = "BIG5",
        Binary = "BINARY",
        Cp1250 = "CP1250",
        Cp1251 = "CP1251",
        Cp1256 = "CP1256",
        Cp1257 = "CP1257",
        Cp850 = "CP850",
        Cp852 = "CP852",
        Cp866 = "CP866",
        Cp932 = "CP932",
        Dec8 = "DEC8",
        Eucjpms = "EUCJPMS",
        Euckr = "EUCKR",
        Gb18030 = "GB18030",
        Gb2312 = "GB2312",
        Gbk = "GBK",
        Geostd8 = "GEOSTD8",
        Greek = "GREEK",
        Hebrew = "HEBREW",
        Hp8 = "HP8",
        Keybcs2 = "KEYBCS2",
        Koi8R = "KOI8R",
        Koi8U = "KOI8U",
        Latin1 = "LATIN1",
        Latin2 = "LATIN2",
        Latin5 = "LATIN5",
        Latin7 = "LATIN7",
        Macce = "MACCE",
        Macroman = "MACROMAN",
        Sjis = "SJIS",
        Swe7 = "SWE7",
        Tis620 = "TIS620",
        Ucs2 = "UCS2",
        Ujis = "UJIS",
        Utf16 = "UTF16",
        Utf16Le = "UTF16LE",
        Utf32 = "UTF32",
        Utf8Mb3 = "UTF8MB3",
        Utf8Mb4 = "UTF8MB4",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum CollationServer {
        Armscii8GeneralCi = "ARMSCII8_GENERAL_CI",
        Armscii8Bin = "ARMSCII8_BIN",
        AsciiGeneralCi = "ASCII_GENERAL_CI",
        AsciiBin = "ASCII_BIN",
        Big5ChineseCi = "BIG5_CHINESE_CI",
        Big5Bin = "BIG5_BIN",
        Binary = "BINARY",
        Cp1250GeneralCi = "CP1250_GENERAL_CI",
        Cp1250Bin = "CP1250_BIN",
        Cp1250CroatianCi = "CP1250_CROATIAN_CI",
        Cp1250CzechCs = "CP1250_CZECH_CS",
        Cp1250PolishCi = "CP1250_POLISH_CI",
        Cp1251GeneralCi = "CP1251_GENERAL_CI",
        Cp1251Bin = "CP1251_BIN",
        Cp1251BulgarianCi = "CP1251_BULGARIAN_CI",
        Cp1251GeneralCs = "CP1251_GENERAL_CS",
        Cp1251UkrainianCi = "CP1251_UKRAINIAN_CI",
        Cp1256GeneralCi = "CP1256_GENERAL_CI",
        Cp1256Bin = "CP1256_BIN",
        Cp1257GeneralCi = "CP1257_GENERAL_CI",
        Cp1257Bin = "CP1257_BIN",
        Cp1257LithuanianCi = "CP1257_LITHUANIAN_CI",
        Cp850GeneralCi = "CP850_GENERAL_CI",
        Cp850Bin = "CP850_BIN",
        Cp852GeneralCi = "CP852_GENERAL_CI",
        Cp852Bin = "CP852_BIN",
        Cp866GeneralCi = "CP866_GENERAL_CI",
        Cp866Bin = "CP866_BIN",
        Cp932JapaneseCi = "CP932_JAPANESE_CI",
        Cp932Bin = "CP932_BIN",
        Dec8SwedishCi = "DEC8_SWEDISH_CI",
        Dec8Bin = "DEC8_BIN",
        EucjpmsJapaneseCi = "EUCJPMS_JAPANESE_CI",
        EucjpmsBin = "EUCJPMS_BIN",
        EuckrKoreanCi = "EUCKR_KOREAN_CI",
        EuckrBin = "EUCKR_BIN",
        Gb18030ChineseCi = "GB18030_CHINESE_CI",
        Gb18030Bin = "GB18030_BIN",
        Gb18030Unicode520Ci = "GB18030_UNICODE_520_CI",
        Gb2312ChineseCi = "GB2312_CHINESE_CI",
        Gb2312Bin = "GB2312_BIN",
        GbkChineseCi = "GBK_CHINESE_CI",
        GbkBin = "GBK_BIN",
        Geostd8GeneralCi = "GEOSTD8_GENERAL_CI",
        Geostd8Bin = "GEOSTD8_BIN",
        GreekGeneralCi = "GREEK_GENERAL_CI",
        GreekBin = "GREEK_BIN",
        HebrewGeneralCi = "HEBREW_GENERAL_CI",
        HebrewBin = "HEBREW_BIN",
        Hp8EnglishCi = "HP8_ENGLISH_CI",
        Hp8Bin = "HP8_BIN",
        Keybcs2GeneralCi = "KEYBCS2_GENERAL_CI",
        Keybcs2Bin = "KEYBCS2_BIN",
        Koi8RGeneralCi = "KOI8R_GENERAL_CI",
        Koi8RBin = "KOI8R_BIN",
        Koi8UGeneralCi = "KOI8U_GENERAL_CI",
        Koi8UBin = "KOI8U_BIN",
        Latin1SwedishCi = "LATIN1_SWEDISH_CI",
        Latin1Bin = "LATIN1_BIN",
        Latin1DanishCi = "LATIN1_DANISH_CI",
        Latin1GeneralCi = "LATIN1_GENERAL_CI",
        Latin1GeneralCs = "LATIN1_GENERAL_CS",
        Latin1German1Ci = "LATIN1_GERMAN1_CI",
        Latin1German2Ci = "LATIN1_GERMAN2_CI",
        Latin1SpanishCi = "LATIN1_SPANISH_CI",
        Latin2GeneralCi = "LATIN2_GENERAL_CI",
        Latin2Bin = "LATIN2_BIN",
        Latin2CroatianCi = "LATIN2_CROATIAN_CI",
        Latin2CzechCs = "LATIN2_CZECH_CS",
        Latin2HungarianCi = "LATIN2_HUNGARIAN_CI",
        Latin5TurkishCi = "LATIN5_TURKISH_CI",
        Latin5Bin = "LATIN5_BIN",
        Latin7GeneralCi = "LATIN7_GENERAL_CI",
        Latin7Bin = "LATIN7_BIN",
        Latin7EstonianCs = "LATIN7_ESTONIAN_CS",
        Latin7GeneralCs = "LATIN7_GENERAL_CS",
        MacceGeneralCi = "MACCE_GENERAL_CI",
        MacceBin = "MACCE_BIN",
        MacromanGeneralCi = "MACROMAN_GENERAL_CI",
        MacromanBin = "MACROMAN_BIN",
        SjisJapaneseCi = "SJIS_JAPANESE_CI",
        SjisBin = "SJIS_BIN",
        Swe7SwedishCi = "SWE7_SWEDISH_CI",
        Swe7Bin = "SWE7_BIN",
        Tis620ThaiCi = "TIS620_THAI_CI",
        Tis620Bin = "TIS620_BIN",
        Ucs2GeneralCi = "UCS2_GENERAL_CI",
        Ucs2Bin = "UCS2_BIN",
        Ucs2CroatianCi = "UCS2_CROATIAN_CI",
        Ucs2CzechCi = "UCS2_CZECH_CI",
        Ucs2DanishCi = "UCS2_DANISH_CI",
        Ucs2EsperantoCi = "UCS2_ESPERANTO_CI",
        Ucs2EstonianCi = "UCS2_ESTONIAN_CI",
        Ucs2GeneralMysql500Ci = "UCS2_GENERAL_MYSQL500_CI",
        Ucs2German2Ci = "UCS2_GERMAN2_CI",
        Ucs2HungarianCi = "UCS2_HUNGARIAN_CI",
        Ucs2IcelandicCi = "UCS2_ICELANDIC_CI",
        Ucs2LatvianCi = "UCS2_LATVIAN_CI",
        Ucs2LithuanianCi = "UCS2_LITHUANIAN_CI",
        Ucs2PersianCi = "UCS2_PERSIAN_CI",
        Ucs2PolishCi = "UCS2_POLISH_CI",
        Ucs2RomanianCi = "UCS2_ROMANIAN_CI",
        Ucs2RomanCi = "UCS2_ROMAN_CI",
        Ucs2SinhalaCi = "UCS2_SINHALA_CI",
        Ucs2SlovakCi = "UCS2_SLOVAK_CI",
        Ucs2SlovenianCi = "UCS2_SLOVENIAN_CI",
        Ucs2Spanish2Ci = "UCS2_SPANISH2_CI",
        Ucs2SpanishCi = "UCS2_SPANISH_CI",
        Ucs2SwedishCi = "UCS2_SWEDISH_CI",
        Ucs2TurkishCi = "UCS2_TURKISH_CI",
        Ucs2Unicode520Ci = "UCS2_UNICODE_520_CI",
        Ucs2UnicodeCi = "UCS2_UNICODE_CI",
        Ucs2VietnameseCi = "UCS2_VIETNAMESE_CI",
        UjisJapaneseCi = "UJIS_JAPANESE_CI",
        UjisBin = "UJIS_BIN",
        Utf16GeneralCi = "UTF16_GENERAL_CI",
        Utf16Bin = "UTF16_BIN",
        Utf16CroatianCi = "UTF16_CROATIAN_CI",
        Utf16CzechCi = "UTF16_CZECH_CI",
        Utf16DanishCi = "UTF16_DANISH_CI",
        Utf16EsperantoCi = "UTF16_ESPERANTO_CI",
        Utf16EstonianCi = "UTF16_ESTONIAN_CI",
        Utf16German2Ci = "UTF16_GERMAN2_CI",
        Utf16HungarianCi = "UTF16_HUNGARIAN_CI",
        Utf16IcelandicCi = "UTF16_ICELANDIC_CI",
        Utf16LatvianCi = "UTF16_LATVIAN_CI",
        Utf16LithuanianCi = "UTF16_LITHUANIAN_CI",
        Utf16PersianCi = "UTF16_PERSIAN_CI",
        Utf16PolishCi = "UTF16_POLISH_CI",
        Utf16RomanianCi = "UTF16_ROMANIAN_CI",
        Utf16RomanCi = "UTF16_ROMAN_CI",
        Utf16SinhalaCi = "UTF16_SINHALA_CI",
        Utf16SlovakCi = "UTF16_SLOVAK_CI",
        Utf16SlovenianCi = "UTF16_SLOVENIAN_CI",
        Utf16Spanish2Ci = "UTF16_SPANISH2_CI",
        Utf16SpanishCi = "UTF16_SPANISH_CI",
        Utf16SwedishCi = "UTF16_SWEDISH_CI",
        Utf16TurkishCi = "UTF16_TURKISH_CI",
        Utf16Unicode520Ci = "UTF16_UNICODE_520_CI",
        Utf16UnicodeCi = "UTF16_UNICODE_CI",
        Utf16VietnameseCi = "UTF16_VIETNAMESE_CI",
        Utf16LeGeneralCi = "UTF16LE_GENERAL_CI",
        Utf16LeBin = "UTF16LE_BIN",
        Utf32GeneralCi = "UTF32_GENERAL_CI",
        Utf32Bin = "UTF32_BIN",
        Utf32CroatianCi = "UTF32_CROATIAN_CI",
        Utf32CzechCi = "UTF32_CZECH_CI",
        Utf32DanishCi = "UTF32_DANISH_CI",
        Utf32EsperantoCi = "UTF32_ESPERANTO_CI",
        Utf32EstonianCi = "UTF32_ESTONIAN_CI",
        Utf32German2Ci = "UTF32_GERMAN2_CI",
        Utf32HungarianCi = "UTF32_HUNGARIAN_CI",
        Utf32IcelandicCi = "UTF32_ICELANDIC_CI",
        Utf32LatvianCi = "UTF32_LATVIAN_CI",
        Utf32LithuanianCi = "UTF32_LITHUANIAN_CI",
        Utf32PersianCi = "UTF32_PERSIAN_CI",
        Utf32PolishCi = "UTF32_POLISH_CI",
        Utf32RomanianCi = "UTF32_ROMANIAN_CI",
        Utf32RomanCi = "UTF32_ROMAN_CI",
        Utf32SinhalaCi = "UTF32_SINHALA_CI",
        Utf32SlovakCi = "UTF32_SLOVAK_CI",
        Utf32SlovenianCi = "UTF32_SLOVENIAN_CI",
        Utf32Spanish2Ci = "UTF32_SPANISH2_CI",
        Utf32SpanishCi = "UTF32_SPANISH_CI",
        Utf32SwedishCi = "UTF32_SWEDISH_CI",
        Utf32TurkishCi = "UTF32_TURKISH_CI",
        Utf32Unicode520Ci = "UTF32_UNICODE_520_CI",
        Utf32UnicodeCi = "UTF32_UNICODE_CI",
        Utf32VietnameseCi = "UTF32_VIETNAMESE_CI",
        Utf8GeneralCi = "UTF8_GENERAL_CI",
        Utf8Bin = "UTF8_BIN",
        Utf8CroatianCi = "UTF8_CROATIAN_CI",
        Utf8CzechCi = "UTF8_CZECH_CI",
        Utf8DanishCi = "UTF8_DANISH_CI",
        Utf8EsperantoCi = "UTF8_ESPERANTO_CI",
        Utf8EstonianCi = "UTF8_ESTONIAN_CI",
        Utf8GeneralMysql500Ci = "UTF8_GENERAL_MYSQL500_CI",
        Utf8German2Ci = "UTF8_GERMAN2_CI",
        Utf8HungarianCi = "UTF8_HUNGARIAN_CI",
        Utf8IcelandicCi = "UTF8_ICELANDIC_CI",
        Utf8LatvianCi = "UTF8_LATVIAN_CI",
        Utf8LithuanianCi = "UTF8_LITHUANIAN_CI",
        Utf8PersianCi = "UTF8_PERSIAN_CI",
        Utf8PolishCi = "UTF8_POLISH_CI",
        Utf8RomanianCi = "UTF8_ROMANIAN_CI",
        Utf8RomanCi = "UTF8_ROMAN_CI",
        Utf8SinhalaCi = "UTF8_SINHALA_CI",
        Utf8SlovakCi = "UTF8_SLOVAK_CI",
        Utf8SlovenianCi = "UTF8_SLOVENIAN_CI",
        Utf8Spanish2Ci = "UTF8_SPANISH2_CI",
        Utf8SpanishCi = "UTF8_SPANISH_CI",
        Utf8SwedishCi = "UTF8_SWEDISH_CI",
        Utf8TolowerCi = "UTF8_TOLOWER_CI",
        Utf8TurkishCi = "UTF8_TURKISH_CI",
        Utf8Unicode520Ci = "UTF8_UNICODE_520_CI",
        Utf8UnicodeCi = "UTF8_UNICODE_CI",
        Utf8VietnameseCi = "UTF8_VIETNAMESE_CI",
        Utf8Mb40900AiCi = "UTF8MB4_0900_AI_CI",
        Utf8Mb40900AsCi = "UTF8MB4_0900_AS_CI",
        Utf8Mb40900AsCs = "UTF8MB4_0900_AS_CS",
        Utf8Mb40900Bin = "UTF8MB4_0900_BIN",
        Utf8Mb4Bin = "UTF8MB4_BIN",
        Utf8Mb4CroatianCi = "UTF8MB4_CROATIAN_CI",
        Utf8Mb4Cs0900AiCi = "UTF8MB4_CS_0900_AI_CI",
        Utf8Mb4Cs0900AsCs = "UTF8MB4_CS_0900_AS_CS",
        Utf8Mb4CzechCi = "UTF8MB4_CZECH_CI",
        Utf8Mb4DanishCi = "UTF8MB4_DANISH_CI",
        Utf8Mb4Da0900AiCi = "UTF8MB4_DA_0900_AI_CI",
        Utf8Mb4Da0900AsCs = "UTF8MB4_DA_0900_AS_CS",
        Utf8Mb4DePb0900AiCi = "UTF8MB4_DE_PB_0900_AI_CI",
        Utf8Mb4DePb0900AsCs = "UTF8MB4_DE_PB_0900_AS_CS",
        Utf8Mb4Eo0900AiCi = "UTF8MB4_EO_0900_AI_CI",
        Utf8Mb4Eo0900AsCs = "UTF8MB4_EO_0900_AS_CS",
        Utf8Mb4EsperantoCi = "UTF8MB4_ESPERANTO_CI",
        Utf8Mb4EstonianCi = "UTF8MB4_ESTONIAN_CI",
        Utf8Mb4Es0900AiCi = "UTF8MB4_ES_0900_AI_CI",
        Utf8Mb4Es0900AsCs = "UTF8MB4_ES_0900_AS_CS",
        Utf8Mb4EsTrad0900AiCi = "UTF8MB4_ES_TRAD_0900_AI_CI",
        Utf8Mb4EsTrad0900AsCs = "UTF8MB4_ES_TRAD_0900_AS_CS",
        Utf8Mb4Et0900AiCi = "UTF8MB4_ET_0900_AI_CI",
        Utf8Mb4Et0900AsCs = "UTF8MB4_ET_0900_AS_CS",
        Utf8Mb4GeneralCi = "UTF8MB4_GENERAL_CI",
        Utf8Mb4German2Ci = "UTF8MB4_GERMAN2_CI",
        Utf8Mb4Hr0900AiCi = "UTF8MB4_HR_0900_AI_CI",
        Utf8Mb4Hr0900AsCs = "UTF8MB4_HR_0900_AS_CS",
        Utf8Mb4HungarianCi = "UTF8MB4_HUNGARIAN_CI",
        Utf8Mb4Hu0900AiCi = "UTF8MB4_HU_0900_AI_CI",
        Utf8Mb4Hu0900AsCs = "UTF8MB4_HU_0900_AS_CS",
        Utf8Mb4IcelandicCi = "UTF8MB4_ICELANDIC_CI",
        Utf8Mb4Is0900AiCi = "UTF8MB4_IS_0900_AI_CI",
        Utf8Mb4Is0900AsCs = "UTF8MB4_IS_0900_AS_CS",
        Utf8Mb4Ja0900AsCs = "UTF8MB4_JA_0900_AS_CS",
        Utf8Mb4Ja0900AsCsKs = "UTF8MB4_JA_0900_AS_CS_KS",
        Utf8Mb4LatvianCi = "UTF8MB4_LATVIAN_CI",
        Utf8Mb4La0900AiCi = "UTF8MB4_LA_0900_AI_CI",
        Utf8Mb4La0900AsCs = "UTF8MB4_LA_0900_AS_CS",
        Utf8Mb4LithuanianCi = "UTF8MB4_LITHUANIAN_CI",
        Utf8Mb4Lt0900AiCi = "UTF8MB4_LT_0900_AI_CI",
        Utf8Mb4Lt0900AsCs = "UTF8MB4_LT_0900_AS_CS",
        Utf8Mb4Lv0900AiCi = "UTF8MB4_LV_0900_AI_CI",
        Utf8Mb4Lv0900AsCs = "UTF8MB4_LV_0900_AS_CS",
        Utf8Mb4PersianCi = "UTF8MB4_PERSIAN_CI",
        Utf8Mb4Pl0900AiCi = "UTF8MB4_PL_0900_AI_CI",
        Utf8Mb4Pl0900AsCs = "UTF8MB4_PL_0900_AS_CS",
        Utf8Mb4PolishCi = "UTF8MB4_POLISH_CI",
        Utf8Mb4RomanianCi = "UTF8MB4_ROMANIAN_CI",
        Utf8Mb4RomanCi = "UTF8MB4_ROMAN_CI",
        Utf8Mb4Ro0900AiCi = "UTF8MB4_RO_0900_AI_CI",
        Utf8Mb4Ro0900AsCs = "UTF8MB4_RO_0900_AS_CS",
        Utf8Mb4Ru0900AiCi = "UTF8MB4_RU_0900_AI_CI",
        Utf8Mb4Ru0900AsCs = "UTF8MB4_RU_0900_AS_CS",
        Utf8Mb4SinhalaCi = "UTF8MB4_SINHALA_CI",
        Utf8Mb4Sk0900AiCi = "UTF8MB4_SK_0900_AI_CI",
        Utf8Mb4Sk0900AsCs = "UTF8MB4_SK_0900_AS_CS",
        Utf8Mb4SlovakCi = "UTF8MB4_SLOVAK_CI",
        Utf8Mb4SlovenianCi = "UTF8MB4_SLOVENIAN_CI",
        Utf8Mb4Sl0900AiCi = "UTF8MB4_SL_0900_AI_CI",
        Utf8Mb4Sl0900AsCs = "UTF8MB4_SL_0900_AS_CS",
        Utf8Mb4Spanish2Ci = "UTF8MB4_SPANISH2_CI",
        Utf8Mb4SpanishCi = "UTF8MB4_SPANISH_CI",
        Utf8Mb4Sv0900AiCi = "UTF8MB4_SV_0900_AI_CI",
        Utf8Mb4Sv0900AsCs = "UTF8MB4_SV_0900_AS_CS",
        Utf8Mb4SwedishCi = "UTF8MB4_SWEDISH_CI",
        Utf8Mb4Tr0900AiCi = "UTF8MB4_TR_0900_AI_CI",
        Utf8Mb4Tr0900AsCs = "UTF8MB4_TR_0900_AS_CS",
        Utf8Mb4TurkishCi = "UTF8MB4_TURKISH_CI",
        Utf8Mb4Unicode520Ci = "UTF8MB4_UNICODE_520_CI",
        Utf8Mb4UnicodeCi = "UTF8MB4_UNICODE_CI",
        Utf8Mb4VietnameseCi = "UTF8MB4_VIETNAMESE_CI",
        Utf8Mb4Vi0900AiCi = "UTF8MB4_VI_0900_AI_CI",
        Utf8Mb4Vi0900AsCs = "UTF8MB4_VI_0900_AS_CS",
        Utf8Mb4Zh0900AsCs = "UTF8MB4_ZH_0900_AS_CS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum DefaultAuthenticationPlugin {
        MysqlNativePassword = "mysql_native_password",
        Sha256Password = "sha256_password",
        CachingSha2Password = "caching_sha2_password",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum TransactionIsolation {
        ReadUncommitted = "READ-UNCOMMITTED",
        ReadCommited = "READ-COMMITED",
        ReadCommitted = "READ-COMMITTED",
        RepeatableRead = "REPEATABLE-READ",
        Serializable = "SERIALIZABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum GroupReplicationConsistency {
        Eventual = "EVENTUAL",
        BeforeOnPrimaryFailover = "BEFORE_ON_PRIMARY_FAILOVER",
        Before = "BEFORE",
        After = "AFTER",
        BeforeAndAfter = "BEFORE_AND_AFTER",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum BinlogRowMetadata {
        Full = "FULL",
        Minimal = "MINIMAL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ExplainFormat {
        Traditional = "TRADITIONAL",
        Json = "JSON",
        Tree = "TREE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum InnodbChangeBuffering {
        None = "NONE",
        Inserts = "INSERTS",
        Deletes = "DELETES",
        Changes = "CHANGES",
        Purges = "PURGES",
        All = "ALL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ConfigurationVariables): object;
    function getDeserializedJsonObj(obj: ConfigurationVariables): object;
}
