/**
 * MySQL Database Service API
 * The API for the MySQL Database Service
 * OpenAPI spec version: 20190415
 * Contact: mysql-cloud-dev_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A summary of a DB System.
 *
 */
export interface DbSystemSummary {
    /**
     * The OCID of the DB System.
     */
    "id": string;
    /**
     * The user-friendly name for the DB System. It does not have to be unique.
     */
    "displayName": string;
    /**
     * User-provided data about the DB System.
     */
    "description"?: string;
    /**
     * The OCID of the compartment the DB System belongs in.
     */
    "compartmentId"?: string;
    /**
     * Specifies if the DB System is highly available.
     *
     */
    "isHighlyAvailable"?: boolean;
    "currentPlacement"?: model.DbSystemPlacement;
    /**
     * If the DB System has a HeatWave Cluster attached.
     *
     */
    "isHeatWaveClusterAttached"?: boolean;
    "heatWaveCluster"?: model.HeatWaveClusterSummary;
    /**
      * The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
  * <p>
  In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains
  * and the MySQL instance in that domain is promoted to the primary instance.
  * This redirection does not affect the IP address of the DB System in any way.
  * <p>
  For a standalone DB System, this defines the availability domain in which the DB System is placed.
  *
      */
    "availabilityDomain"?: string;
    /**
      * The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
  * <p>
  In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains
  * and the MySQL instance in that domain is promoted to the primary instance.
  * This redirection does not affect the IP address of the DB System in any way.
  * <p>
  For a standalone DB System, this defines the fault domain in which the DB System is placed.
  *
      */
    "faultDomain"?: string;
    /**
     * The network endpoints available for this DB System.
     *
     */
    "endpoints"?: Array<model.DbSystemEndpoint>;
    /**
     * The current state of the DB System.
     */
    "lifecycleState": string;
    /**
     * Name of the MySQL Version in use for the DB System.
     */
    "mysqlVersion": string;
    /**
     * The date and time the DB System was created.
     */
    "timeCreated": Date;
    /**
     * The time the DB System was last updated.
     */
    "timeUpdated": Date;
    "deletionPolicy"?: model.DeletionPolicyDetails;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    "backupPolicy"?: model.BackupPolicy;
    /**
     * The shape of the primary instances of the DB System. The shape
     * determines resources allocated to a DB System - CPU cores
     * and memory for VM shapes; CPU cores, memory and storage for non-VM
     * (or bare metal) shapes. To get a list of shapes, use (the
     * {@link #listShapes(ListShapesRequest) listShapes} operation.
     *
     */
    "shapeName"?: string;
    /**
     * Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled,
     * and whether to enable or disable syncing of the Binary Logs.
     *
     */
    "crashRecovery"?: model.CrashRecoveryStatus;
    /**
     * Whether to enable monitoring via the Database Management service.
     *
     */
    "databaseManagement"?: model.DatabaseManagementStatus;
    /**
     * The database mode indicating the types of statements that are allowed to run in the DB system.
     * This mode applies only to statements run by user connections. Replicated write statements continue
     * to be allowed regardless of the DatabaseMode.
     *   - READ_WRITE: allow running read and write statements on the DB system;
     *   - READ_ONLY: only allow running read statements on the DB system.
     *
     */
    "databaseMode": string;
    /**
     * The access mode indicating if the database access is unrestricted (to all MySQL user accounts),
     * or restricted (to only certain users with specific privileges):
     *  - UNRESTRICTED: the access to the database is not restricted;
     *  - RESTRICTED: the access is allowed only to users with specific privileges;
     *    RESTRICTED will correspond to setting the MySQL system variable
     *    [offline_mode](https://dev.mysql.com/doc/en/server-system-variables.html#sysvar_offline_mode) to ON.
     *
     */
    "accessMode": string;
    "readEndpoint"?: model.ReadEndpointDetails;
}
export declare namespace DbSystemSummary {
    function getJsonObj(obj: DbSystemSummary): object;
    function getDeserializedJsonObj(obj: DbSystemSummary): object;
}
